"hills" <-
structure(list(dist = c(2.4, 6, 6, 7.5, 8, 8, 16, 6, 5, 6, 28, 
5, 9.5, 6, 4.5, 10, 14, 3, 4.5, 5.5, 3, 3.5, 6, 2, 3, 4, 6, 5, 
6.5, 5, 10, 6, 18, 4.5, 20), climb = c(650, 2500, 900, 800, 3070, 
2866, 7500, 800, 800, 650, 2100, 2000, 2200, 500, 1500, 3000, 
2200, 350, 1000, 600, 300, 1500, 2200, 900, 600, 2000, 800, 950, 
1750, 500, 4400, 600, 5200, 850, 5000), time = c(0.268055555555556, 
0.805833333333333, 0.560833333333333, 0.76, 1.03777777777778, 
1.22027777777778, 3.41027777777778, 0.606111111111111, 0.495833333333333, 
0.6625, 3.21111111111111, 0.7175, 1.08333333333333, 0.735555555555556, 
0.448888888888889, 1.20416666666667, 1.64027777777778, 1.31083333333333, 
0.290277777777778, 0.542777777777778, 0.265833333333333, 0.465, 
0.794166666666667, 0.298888888888889, 0.311388888888889, 0.436944444444444, 
0.573888888888889, 0.476111111111111, 0.841666666666667, 0.349166666666667, 
1.42638888888889, 0.539722222222222, 2.8375, 0.468333333333333, 
2.66388888888889)), .Names = c("dist", "climb", "time"), row.names = c("Greenmantle", 
"Carnethy", "Craig Dunain", "Ben Rha", "Ben Lomond", "Goatfell", 
"Bens of Jura", "Cairnpapple", "Scolty", "Traprain", "Lairig Ghru", 
"Dollar", "Lomonds", "Cairn Table", "Eildon Two", "Cairngorm", 
"Seven Hills", "Knock Hill", "Black Hill", "Creag Beag", "Kildcon Hill", 
"Meall Ant-Suidhe", "Half Ben Nevis", "Cow Hill", "N Berwick Law", 
"Creag Dubh", "Burnswark", "Largo Law", "Criffel", "Acmony", 
"Ben Nevis", "Knockfarrel", "Two Breweries", "Cockleroi", "Moffat Chase"
), class = "data.frame")
